package com.ruoyi.app.mapper;

import com.ruoyi.app.domain.AppGoodsType;

import java.util.List;

/**
 * 物料类别管理Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-04
 */
public interface AppGoodsTypeMapper 
{
    /**
     * 查询物料类别管理
     * 
     * @param typeId 物料类别管理主键
     * @return 物料类别管理
     */
    public AppGoodsType selectAppGoodsTypeByTypeId(Long typeId);

    /**
     * 查询物料类别管理列表
     * 
     * @param appGoodsType 物料类别管理
     * @return 物料类别管理集合
     */
    public List<AppGoodsType> selectAppGoodsTypeList(AppGoodsType appGoodsType);

    /**
     * 新增物料类别管理
     * 
     * @param appGoodsType 物料类别管理
     * @return 结果
     */
    public int insertAppGoodsType(AppGoodsType appGoodsType);

    /**
     * 修改物料类别管理
     * 
     * @param appGoodsType 物料类别管理
     * @return 结果
     */
    public int updateAppGoodsType(AppGoodsType appGoodsType);

    /**
     * 删除物料类别管理
     * 
     * @param typeId 物料类别管理主键
     * @return 结果
     */
    public int deleteAppGoodsTypeByTypeId(Long typeId);

    /**
     * 批量删除物料类别管理
     * 
     * @param typeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppGoodsTypeByTypeIds(Long[] typeIds);
}
